package de.intevation.flys.artifacts.math.fitting;

public class Quad
extends      Function
{
    public static final Derivative DERIVATIVE =
        new Derivative("W'(Q) = 2*n*Q+m") {

        @Override
        public de.intevation.flys.artifacts.math.Function
            instantiate(double [] parameters)
        {
            final double n = parameters[0];
            final double m = parameters[1];

            return new de.intevation.flys.artifacts.math.Function() {
                @Override
                public double value(double Q) {
                    return 2*n*Q+m;
                }
            };
        }
    };

    public Quad() {
        super(
            "quad",
            "W(Q) = n*Q^2 + m*Q + b",
            new String [] { "n", "m", "b" });
    }

    @Override
    public double value(double x, double [] parameters) {
        // n*Q^2 + m*Q + b <=> Q*(n*Q + m) + b
        return x*(parameters[0]*x + parameters[1]) + parameters[2];
    }

    @Override
    public double [] gradient(double x, double [] parameters) {
        return new double [] { x*x, x, 1d };
    }

    @Override
    public Derivative getDerivative() {
        return DERIVATIVE;
    }

    @Override
    public Function getInverse() {
        return InvQuad.INSTANCE;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
